@@ -13,15 +13,16 @@
 // [CLASS] Frame
 //============================================================================
 define([
-    'text!vp_base/html/m_apps/frame.html!strip',
-    'css!vp_base/css/m_apps/frame.css',
+    __VP_TEXT_LOADER__('vp_base/html/m_apps/frame.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/m_apps/frame'), // INTEGRATION: unified version of css loader
+    'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
     'vp_base/js/com/component/PopupComponent',
     'vp_base/js/com/component/SuggestInput',
-    'vp_base/js/com/component/VarSelector',
+    'vp_base/js/com/component/DataSelector',
     'vp_base/js/m_apps/Subset'
-], function(frameHtml, frameCss, com_String, com_util, PopupComponent, SuggestInput, VarSelector, Subset) {
+], function(frameHtml, frameCss, com_Const, com_String, com_util, PopupComponent, SuggestInput, DataSelector, Subset) {
 
     /**
      * Frame
@@ -515,7 +516,14 @@ define([
         }
 
         templateForBody() {
-            return frameHtml;
+            let page = $(frameHtml);
+
+            let allocateSelector = new DataSelector({
+                pageThis: this, id: 'vp_feReturn', placeholder: 'Variable name', required: true, value: '_vp'
+            });
+            $(page).find('#vp_feReturn').replaceWith(allocateSelector.toTagString());
+
+            return page;
         }
 
         render() {
@@ -838,7 +846,9 @@ define([
             content.appendFormatLine('<input type="text" class="{0}" placeholder="{1}"/>', 'vp-inner-popup-replace' + index, 'Replace');
             content.appendFormatLine('<label><input type="checkbox" class="{0}" checked/><span>{1}</span></label>', 'vp-inner-popup-replace-istext' + index, 'Text');
             content.appendLine('</td>');
-            content.appendFormatLine('<td><div class="{0} {1}"><img src="{2}"/></div></td>', 'vp-inner-popup-delete', 'vp-cursor', '/nbextensions/visualpython/img/close_small.svg');
+            // LAB: img to url
+            // content.appendFormatLine('<td><div class="{0} {1}"><img src="{2}"/></div></td>', 'vp-inner-popup-delete', 'vp-cursor', com_Const.IMAGE_PATH + 'close_small.svg');
+            content.appendFormatLine('<td><div class="{0} {1} {2}"></div></td>', 'vp-inner-popup-delete', 'vp-cursor', 'vp-icon-close-small');
             content.appendLine('</tr>');
             return content.toString();
         }
@@ -1171,43 +1181,48 @@ define([
             // code.append(".value_counts()");
             code.appendFormat('_vp_display_dataframe_info({0})', locObj.toString());
     
-            Jupyter.notebook.kernel.execute(
-                code.toString(),
-                {
-                    iopub: {
-                        output: function(msg) {
-                            if (msg.content.data) {
-                                var htmlText = String(msg.content.data["text/html"]);
-                                var codeText = String(msg.content.data["text/plain"]);
-                                if (htmlText != 'undefined') {
-                                    $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
-                                        return that.renderInfoPage(htmlText);
-                                    });
-                                } else if (codeText != 'undefined') {
-                                    // plain text as code
-                                    $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
-                                        return that.renderInfoPage(codeText, false);
-                                    });
-                                } else {
-                                    $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
-                                        return that.renderInfoPage('');
-                                    });
-                                }
-                            } else {
-                                var errorContent = '';
-                                if (msg.content.ename) {
-                                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
-                                }
-                                vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
-                                $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
-                                    return that.renderInfoPage(errorContent);
-                                });
-                            }
-                        }
+            // CHROME: TODO: 6: use com_Kernel.execute
+            // Jupyter.notebook.kernel.execute(
+            vpKernel.execute(code.toString()).then(function(resultObj) {
+                let { msg } = resultObj;
+                if (msg.content.data) {
+                    var htmlText = String(msg.content.data["text/html"]);
+                    var codeText = String(msg.content.data["text/plain"]);
+                    if (htmlText != 'undefined') {
+                        $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
+                            return that.renderInfoPage(htmlText);
+                        });
+                    } else if (codeText != 'undefined') {
+                        // plain text as code
+                        $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
+                            return that.renderInfoPage(codeText, false);
+                        });
+                    } else {
+                        $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
+                            return that.renderInfoPage('');
+                        });
                     }
-                },
-                { silent: false, store_history: true, stop_on_error: true }
-            );
+                } else {
+                    var errorContent = '';
+                    if (msg.content.ename) {
+                        errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                    }
+                    vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
+                    $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
+                        return that.renderInfoPage(errorContent);
+                    });
+                }
+            }).catch(function(resultObj) {
+                let { msg } = resultObj;
+                var errorContent = '';
+                if (msg.content.ename) {
+                    errorContent = com_util.templateForErrorBox(msg.content.ename, msg.content.evalue);
+                }
+                vpLog.display(VP_LOG_TYPE.ERROR, msg.content.ename, msg.content.evalue, msg.content);
+                $(that.wrapSelector('.' + VP_FE_INFO_CONTENT)).replaceWith(function() {
+                    return that.renderInfoPage(errorContent);
+                });
+            })
         }
 
         getTypeCode(type, content={}) {
@@ -1417,7 +1432,9 @@ define([
                                                             , colCode, FRAME_AXIS.COLUMN, col.type, VP_FE_TABLE_COLUMN, colClass, col.label);
                                 });
                                 // add column
-                                table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_COLUMN, '/nbextensions/visualpython/img/plus.svg');
+                                // LAB: img to url
+                                // table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_COLUMN, com_Const.IMAGE_PATH + 'plus.svg');
+                                table.appendFormatLine('<th class="{0} {1}"></th>', VP_FE_ADD_COLUMN, 'vp-icon-plus');
                 
                                 table.appendLine('</tr>');
                                 table.appendLine('</thead>');
@@ -1448,7 +1465,9 @@ define([
                                 });
                                 // add row
                                 table.appendLine('<tr>');
-                                table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_ROW, '/nbextensions/visualpython/img/plus.svg');
+                                // LAB: img to url
+                                // table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_ROW, com_Const.IMAGE_PATH + 'plus.svg');
+                                table.appendFormatLine('<th class="{0} {1}"></th>', VP_FE_ADD_ROW, 'vp-icon-plus');
                                 table.appendLine('</tr>');
                                 table.appendLine('</tbody>');
                                 $(that.wrapSelector('.' + VP_FE_TABLE)).replaceWith(function() {
