@@ -13,7 +13,7 @@
 // [CLASS] Import
 //============================================================================
 define([
-    'css!vp_base/css/m_apps/import.css',
+    __VP_CSS_LOADER__('vp_base/css/m_apps/import'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_util',
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
@@ -36,7 +36,7 @@ define([
                 , include: [
                     'from plotly.offline import init_notebook_mode',
                     'init_notebook_mode(connected=True)'
-                ]
+                ], checked: false
             }
         ],
         'machine-learning': [
@@ -195,7 +195,9 @@ define([
             tag.appendFormat('<td style="{0}">as</td>', 'text-align="center";');
             tag.appendFormat('<td><input id="{0}" type="text" class="{1}" placeholder="{2}" value="{3}"/></td>'
                             , 'vp_i1_' + idx, 'vp-input m vp-add-i1', 'Type alias', aliasName);
-            tag.appendFormat('<td class="{0}"><img src="{1}"/></td>', 'vp-remove-option w100 vp-cursor', '/nbextensions/visualpython/img/close_small.svg');
+            // LAB: img to url
+            // tag.appendFormat('<td class="{0}"><img src="{1}"/></td>', 'vp-remove-option w100 vp-cursor', com_Const.IMAGE_PATH + 'close_small.svg');
+            tag.appendFormat('<td class="{0} {1}"></td>', 'vp-remove-option w100 vp-cursor', 'vp-icon-close-small');
             tag.append('</tr>');
             return tag.toString();
         }
@@ -213,7 +215,9 @@ define([
             tag.appendFormat('<td style="{0}">import</td>', 'text-align="center";');
             tag.appendFormat('<td><input id="{0}" type="text" class="{1}" placeholder="{2}" value="{3}"/></td>'
                             , 'vp_i1_' + idx, 'vp-input m vp-add-i1', 'Type function', functionName);
-            tag.appendFormat('<td class="{0}"><img src="{1}"/></td>', 'vp-remove-option w100 vp-cursor', '/nbextensions/visualpython/img/close_small.svg');
+            // LAB: img to url
+            // tag.appendFormat('<td class="{0}"><img src="{1}"/></td>', 'vp-remove-option w100 vp-cursor', com_Const.IMAGE_PATH + 'close_small.svg');
+            tag.appendFormat('<td class="{0} {1}"></td>', 'vp-remove-option w100 vp-cursor', 'vp-icon-close-small');
             tag.append('</tr>');
             return tag.toString();
         }
