@@ -13,8 +13,8 @@
 // [CLASS] Chart
 //============================================================================
 define([
-    'text!vp_base/html/m_visualize/chart.html!strip',
-    'css!vp_base/css/m_visualize/chart.css',
+    __VP_TEXT_LOADER__('vp_base/html/m_visualize/chart.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/m_visualize/chart'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_util',
@@ -34,6 +34,7 @@ define([
             /** Write codes executed before rendering */
             this.config.dataview = false;
             this.config.sizeLevel = 2;
+            this.config.checkModules = ['plt'];
             
             this.setDefaultVariables();
             this.state = {
@@ -78,6 +79,9 @@ define([
                         if (obj.required != false) {
                             // label = "* " + obj.label;
                             $(that.wrapSelector('#' + obj.name)).closest('tr').find('th').addClass('vp-orange-text');
+                            $(that.wrapSelector('#' + obj.name)).attr({'required': true});
+                        } else {
+                            $(that.wrapSelector('#' + obj.name)).attr({'required': false});
                         }
                         // $(that.wrapSelector("label[for='" + obj.name + "']")).text(label);
                         $(that.wrapSelector('#' + obj.name)).closest('tr').find('th').text(label);
@@ -159,7 +163,7 @@ define([
         }
 
         templateForBody() {
-            return chartHTml
+            return chartHTml;
         }
 
         loadState() {
@@ -338,6 +342,9 @@ define([
                     if (obj.required != false) {
                         // label = "* " + obj.label;
                         $(this.wrapSelector('#' + obj.name)).closest('tr').find('th').addClass('vp-orange-text');
+                        $(this.wrapSelector('#' + obj.name)).attr({'required': true});
+                    } else {
+                        $(this.wrapSelector('#' + obj.name)).attr({'required': false});
                     }
                     // $(this.wrapSelector("label[for='" + obj.name + "']")).text(label);
                     $(this.wrapSelector('#' + obj.name)).closest('tr').find('th').text(label);
@@ -407,17 +414,17 @@ define([
             var that = this;
             
             let xSelector = new DataSelector({
-                pageThis: this, id: 'x', placeholder: 'Select data'
+                pageThis: this, id: 'x'
             });
             $(this.wrapSelector('#x')).replaceWith(xSelector.toTagString());
 
             let ySelector = new DataSelector({
-                pageThis: this, id: 'y', placeholder: 'Select data'
+                pageThis: this, id: 'y', required: true
             });
             $(this.wrapSelector('#y')).replaceWith(ySelector.toTagString());
 
             let zSelector = new DataSelector({
-                pageThis: this, id: 'z', placeholder: 'Select data'
+                pageThis: this, id: 'z'
             });
             $(this.wrapSelector('#z')).replaceWith(zSelector.toTagString());
         }
@@ -563,10 +570,11 @@ define([
             var fontSize = $(this.wrapSelector('#vp_plFontSize')).val();
     
             code.appendLine('import matplotlib.pyplot as plt');
-            code.appendFormatLine("plt.rc('figure', figsize=({0}, {1}))", figWidth, figHeight);
+            code.appendLine('%matplotlib inline');
             if (styleName && styleName.length > 0) {
                 code.appendFormatLine("plt.style.use('{0}')", styleName);
             }
+            code.appendFormatLine("plt.rc('figure', figsize=({0}, {1}))", figWidth, figHeight);
             code.appendLine();
     
             code.appendLine('from matplotlib import rcParams');
@@ -639,8 +647,10 @@ define([
                 sbCode.append('plt.show()');
 
             } catch (exmsg) {
-                // 에러 표시
-                com_util.renderAlertModal(exmsg);
+                // show error on alert modal
+                if (this.isHidden() == false) {
+                    com_util.renderAlertModal(exmsg);
+                }
             }
     
             return sbCode.toString();
