@@ -13,8 +13,8 @@
 // [CLASS] WordCloud
 //============================================================================
 define([
-    'text!vp_base/html/m_visualize/wordCloud.html!strip',
-    'css!vp_base/css/m_visualize/wordCloud.css',
+    __VP_TEXT_LOADER__('vp_base/html/m_visualize/wordCloud.html'), // INTEGRATION: unified version of text loader
+    __VP_CSS_LOADER__('vp_base/css/m_visualize/wordCloud'), // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
     'vp_base/js/com/component/PopupComponent',
